@@ -4,6 +4,7 @@ from omgeo.places import PlaceQuery
 from omgeo.postprocessors import DupePicker, SnapPoints
 import time
 
+logger = logging.getLogger(__name__)
 stats_logger = logging.getLogger('omgeo.stats')
 
 class Geocoder():
@@ -33,10 +34,16 @@ class Geocoder():
             raise Exception("%s" % (ex))
 
     def add_source(self, source):
+        """
+        Add a geocoding service to this instance.
+        """
         geocode_service = self._get_service_by_name(source[0])
         self._sources.append(geocode_service(**source[1]))
 
     def remove_source(self, source):
+        """
+        Remove a geocoding service from this instance.
+        """
         geocode_service = self._get_service_by_name(source[0])
         self._sources.remove(geocode_service(**source[1]))        
 
@@ -75,13 +82,14 @@ class Geocoder():
         self.set_sources(sources)
         self.waterfall = waterfall
         
-    def geocode(self, pq, waterfall=None):
+    def geocode(self, pq, waterfall=None, force_stats_logging=False):
         """
         :arg PlaceQuery pq:  PlaceQuery object (required).
         :arg bool waterfall: Boolean set to True if all geocoders listed should
                              be used to find results, instead of stopping after
                              the first geocoding service with valid candidates
                              (defaults to self.waterfall).
+        :arg bool force_stats_logging: Raise exception if stats logging fails (default False).
         :returns: Returns a dictionary including:
                    * candidates - list of Candidate objects
                    * upstream_response_info - list of UpstreamResponseInfo objects
@@ -117,10 +125,18 @@ class Geocoder():
                       upstream_response_info=upstream_response_info_list)
         stats_dict = self.convert_geocode_result_to_nested_dicts(result)
         stats_dict = dict(stats_dict, original_pq=pq.__dict__)
-        stats_logger.info(stats_dict)
+        try:
+            stats_logger.info(stats_dict)
+        except Exception as exception:
+            logger.error('Encountered exception while logging stats %s:\n%s', stats_dict, exception)
+            if force_stats_logging:
+                raise exception
         return result
     
     def get_candidates(self, pq, waterfall=None):
+        """
+        Geocode and return just the list of Candidate objects.
+        """
         return self.geocode(pq, waterfall)['candidates']
     
     def convert_geocode_result_to_nested_dicts(self, result):
